sparc.client.services package
=============================

Submodules
----------

sparc.client.services.o2sparc module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: sparc.client.services.o2sparc
   :members:
   :undoc-members:
   :show-inheritance:

sparc.client.services.pennsieve module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: sparc.client.services.pennsieve
   :members:
   :undoc-members:
   :show-inheritance:

sparc.client.services.metadata module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: sparc.client.services.metadata
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
~~~~~~~~~~~~~~~

.. automodule:: sparc.client.services
   :members:
   :undoc-members:
   :show-inheritance:
